import { visit, concatAST, Kind } from 'graphql';
import { AwsAmplifyAngularVisitor } from './visitor';
import { extname } from 'path';
export const plugin = (schema, documents, config) => {
    const allAst = concatAST(documents.reduce((prev, v) => {
        return [...prev, v.content];
    }, []));
    const operations = allAst.definitions.filter(d => d.kind === Kind.OPERATION_DEFINITION);
    if (operations.length === 0) {
        return '';
    }
    const allFragments = allAst.definitions.filter(d => d.kind === Kind.FRAGMENT_DEFINITION);
    const visitor = new AwsAmplifyAngularVisitor(allFragments, operations, config);
    const visitorResult = visit(allAst, { leave: visitor });
    return [
        visitor.getImports(),
        visitor.fragments,
        ...visitorResult.definitions.filter(t => typeof t === 'string'),
        visitor.buildService()
    ].join('\n');
};
export const validate = async (schema, documents, config, outputFile) => {
    if (extname(outputFile) !== '.ts') {
        throw new Error(`Plugin "typescript-aws-amplify-angular" requires extension to be ".ts"!`);
    }
};
//# sourceMappingURL=index.js.map