import { ClientSideBaseVisitor } from 'graphql-codegen-visitor-plugin-common';
import * as autoBind from 'auto-bind';
export class AwsAmplifyAngularVisitor extends ClientSideBaseVisitor {
    constructor(fragments, _allOperations, rawConfig) {
        super(fragments, rawConfig, {});
        this._allOperations = _allOperations;
        this.generatedAPIs = [];
        autoBind(this);
    }
    getImports() {
        const baseImports = super.getImports();
        const imports = [
            `import { Injectable } from '@angular/core';`,
            `import API, { graphqlOperation } from '@aws-amplify/api';`,
            `import { GraphQLResult } from "@aws-amplify/api/lib/types";`,
            `import * as Observable from 'zen-observable';`
        ];
        return [baseImports, ...imports].join('\n');
    }
    buildService() {
        const apis = this.generatedAPIs.map(name => `${name.replace(/API$/i, '')} = ${name};`);
        return `
      @Injectable({
        providedIn: 'root'
      })
      export class APIService {
        ${apis.join('\n')}
      }
    `;
    }
    OperationDefinition(node) {
        return super.OperationDefinition(node);
    }
    buildOperation(node, documentVariableName, operationType, operationResultType, operationVariablesTypes) {
        const isSubscription = operationType === 'Subscription';
        const hasVariables = node.variableDefinitions.length > 0;
        const name = this.convertName(node, {
            suffix: isSubscription ? 'ListenerAPI' : 'API'
        });
        this.generatedAPIs.push(name);
        const field = node.selectionSet.selections[0];
        const fieldName = field.alias ? field.alias.value : field.name.value;
        const variables = hasVariables ? `variables: ${operationVariablesTypes}` : '';
        if (isSubscription) {
            this.generatedAPIs.push(name);
            return `
        const ${name}: Observable<${operationResultType}> = API.graphql(graphqlOperation(${documentVariableName})) as Observable<${operationResultType}>
      `;
        }
        const graphqlOperation = 'graphqlOperation(' + (hasVariables ? `${documentVariableName}, variables` : documentVariableName) + ')';
        return `
      async function ${name}(${variables}): Promise<${operationResultType}> {
        const response = (await API.graphql(${graphqlOperation})) as any;
        return <${operationResultType}>response.data.${fieldName};
      }
    `;
    }
}
//# sourceMappingURL=visitor.js.map